/********************************************
  ACTIVITY COMMON
*********************************************/
var favoriteActivityTypeArray, currentActivityTypeId, currentActivityId;


/* Called when favorite icon is clicked make a food favorite or not */
function toggleFavoriteActivity(){
  if($('.favorite').attr('id') == 'favorite-on') {
    $('.favorite').attr('id','favorite-off')
  } else {
    $('.favorite').attr('id','favorite-on')
  }
}




function logActivityErrorFunction(xhr, ajaxOptions, thrownError){
  log("logActivityErrorFunction");
  alert("Error: " + xhr.status + " - " + thrownError);
}


/* Called when an activity was added */
function logActivitySuccessFunction(data){
  log("logActivitySuccessFunction");

  var dataObject = parseJSON(data);
  var errorMessage = errorToString(dataObject);

  if(errorMessage){
    var errorMessage = "Error:\n" + errorMessage;
    alert(errorMessage);
    return;
  }
  loadPage(ACTIVITY_PAGE);
}


/********************************************
  ACTIVITY UTILS
*********************************************/

/* Utils for the daily activity screen */
/* CONSTANTS  */
/* Web services */
var ACTIVITY_ADD_WS            = SERVER_WS + "activity/add/";
var ACTIVITY_DELETE_WS         = SERVER_WS + "activity/delete/";
var ACTIVITY_EDIT_WS           = SERVER_WS + "activity/edit/";
var FAVORITE_ACTIVITY_TOGGLE_WS      = SERVER_WS + "activity/toggleFavorite";

// Cookies
var CURRENT_ACTIVITY_TYPE_COOKIE = "current_activity_type_cookie";
var CURRENT_ACTIVITY_COOKIE = "current_activity_cookie";

/* Return the food having an food id (id) */
function getActivityType(activityTypeId){
  for(var i=0;i<activityTypeArray.length;i++){
    if(activityTypeArray[i].activityTypeId == parseInt(activityTypeId)){
      return activityTypeArray[i];
    }
  }
  log("ERROR: unknown activityType for id = " + activityTypeId);
  return null;
}

/* Return the food having an food id (id) */
function getActivity(activityId){
  // Regular activity
  for(var i=0;i<activityArray.length;i++){
    if(activityArray[i].activityId == activityId){
      return activityArray[i];
    }
  }
  // Favorite activity
  for(var i = 0; i < favoriteActivityArray.length; i++){
    if(favoriteActivityArray[i].activityId == activityId){
      return favoriteActivityArray[i];
    }
  }

  log("ERROR: unknown activity for id = " + activityId);
  return null;
}




/********************************************
  ACTIVITY MAIN
*********************************************/

var arrayDevices, synced = false;
//var fluidCnt;

function onReadyActivity() {
  document.addEventListener("backbutton", onBackKeyDown, false);
  $("#current_date_span").text(niceFormatDate(currentDate()));
  var crtDate = currentDate();
  if(crtDate==todayDate()){
    $("#tomorrow_button").hide();
  } else {
    Lungo.Events.init({
      'tap #tomorrow_button': tomorrow
    });
  }
  checkNewStaticData(enableOrNotTheCloudButton);
}

function enableOrNotTheCloudButton(yesOrNo){
  log("enableOrNotTheCloudButton (" + yesOrNo + ")");

  if(yesOrNo==YES) {
    $("#cloud_button").show();
  }
  updatePage();
}


function updateStaticDataOnFoodPage(){
  // Lungo.Notification.loading();
  updateStaticData(refreshFoodPage);
}


function refreshFoodPage(){
  setTimeout(reloadFoodPage, 2000);
}


function reloadFoodPage(){
  location.reload();
}


/*update the daily food page details*/
function updatePage(){
  log("updatePage - Activity");
  var postData = {
    token: token,
    date: currentDate(),
    dataname:"User,Activity,FavoriteActivity,ProfileData,Plan,Device"
  };

  sendAjax(
           'POST',
           DYNAMIC_DATA_WS,
           postData,
           updatePageSuccess,
           onError
           );
}


function updatePageSuccess(data){
  log("updatePageSuccess - Activity");
  var dataObject = parseJSON(data);
  //log("data = \n---\n" + JSON.stringify(dataObject) +"\n---");

  //check if the user is still logged in
  if(isUserLoggedIn (dataObject) == NO){
    eraseCookie(TOKEN_COOKIE_NAME);
    loadPage(LOGIN_PAGE);
    return;
  }

  if(dataObject!=null) {
    setMenuTitle(dataObject.UserInfo);

    var array;

    // User's plan
    var plan = dataObject.Plan;
    displayPlanInfo(plan);


    array = dataObject.Activity;
    if(array){
      log("Activity downloaded. Saving to database");
      deleteAllActivities();
      for (var i = 0; i < array.length; i++) {
        var crtActivity = array[i];
        if(crtActivity.is_deleted !=YES){
          insertActivity(array[i]);
        }
      }
    }

    array = dataObject.FavoriteActivity;
    if(array){
      log("Favorite Activity downloaded. Saving to database");
      deleteAllFavoriteActivities();
      for (var i = 0; i < array.length; i++) {
        var crtActivity = array[i];
        if(crtActivity.is_deleted != YES){
          insertFavoriteActivity(array[i]);
        }
      }
    }

    // User devices
    arrayDevices = dataObject.Device;
    if(arrayDevices){
      for(var i = 0; i < arrayDevices.length; i++){
        var crtDevice = arrayDevices[i];
        if(crtDevice.type == "pedometer"){
          synced = true;
        }
      }
    }
  }

  log("Loading data from database");
  startLoadingDataFromDatabase(generateActivityPage);
}

/* Generate the table of meals*/
function generateActivityPage(){
  log("generateActivityPage");
  setDeviceStatus();
  var wrap = $('#activity_div');
  var foodDivElement = $('<ul>');
  log("Activity array: " + activityArray.length);

  for (var i = 0; i < activityArray.length; i++) {
    var crtItem = activityArray[i];

    var activityDate = crtItem.dateTime.replace(" 00:00:00", "");
    if(activityDate == currentDate()){
      var template = "<li class='selectable activityedit' id='?'><div class='right'>(? ?)</div>? - ?<small>?</small></li>";
      //display the activity Type
      var activityType = getActivityType(crtItem.activityTypeId);

      var crtFoodHtml = applyTemplate(template,
                        [crtItem.activityId,crtItem.duration,crtItem.durationUnit,crtItem.name,activityType.name,crtItem.notes]);

      foodDivElement.append(crtFoodHtml);
    }
  }

  wrap.html(foodDivElement);
  Lungo.Notification.hide();
  Lungo.Events.init({
    'tap section#activity .activityedit': function() {
      createCookie(CURRENT_ACTIVITY_COOKIE,$(this).attr('id'));
      onReadyActivityEdit();
    }
  });
}

function setDeviceStatus(){
  // Pedometer synched check
  $("span#device_status").removeClass("green_caption");
  $("span#pedometer_status").removeClass("synced");
  $("span#device_status").addClass("red_caption");
  $("span#device_status").html("Not Synced");
  $("span#pedometer_status").addClass("unsynced");

  if(synced){
    $("span#device_status").removeClass("red_caption");
    $("span#pedometer_status").removeClass("unsynced");
    $("span#device_status").addClass("green_caption");
    $("span#device_status").html("Synced");
    $("span#pedometer_status").addClass("synced");
  }
}




/********************************************
  ACTIVITY ADD
*********************************************/

function onReadyActivityAdd() { startLoadingDataFromDatabase(updatePageActivityAdd); }

/* Update the activity add page details */
function updatePageActivityAdd(){
  updateDurationAddSelect();
  updateIntensityAddSelect();
  currentActivityId = readCookie(CURRENT_ACTIVITY_COOKIE);
  eraseCookie(CURRENT_ACTIVITY_COOKIE);
  $('section#activity_add .favorite').attr('id','favorite-off');
  if(currentActivityId){
    var currentActivity = getActivity(currentActivityId);
    currentActivityTypeId = currentActivity.activityTypeId;
    $("section#activity_add #activity_type").val(currentActivity.activityTypeId);
    $("section#activity_add #duration_select").val(currentActivity.duration);
    $("section#activity_add #intensity_select").val(currentActivity.activityIntensityId);
    $("section#activity_add #notes_textarea").text(currentActivity.notes);
    $("section#activity_add #name").val(currentActivity.name);
  } else {
    $("section#activity_add #activity_type").val('');
    $("section#activity_add #duration_select").val('');
    $("section#activity_add #intensity_select").val('');
    $("section#activity_add #notes_textarea").text('');
    $("section#activity_add #name").val('');
    log("ERROR: currentActivityId and currentActivityTypeId are null or New Activity");
  }
  Lungo.Router.section("activity_add");
}

/* Generate the drop down duration select */
function updateDurationAddSelect(){
  var dropdownList = $("section#activity_add #duration_select")[0];
  //clear the current options if any
  while(dropdownList.options.length > 0){
    dropdownList.remove(0);
  }

  for(var i=5;i<=60;i+=5){
    var option = new Option(i, i);
    dropdownList.add(option, null);
  }

}

/* Generate the drop down intensity select */
function updateIntensityAddSelect(){
  var dropdownList = $("section#activity_add #intensity_select")[0];
  //clear the current options if any
  while(dropdownList.options.length > 0){
    dropdownList.remove(0);
  }

  $.each(activityIntensityArray,
         function() {
          var option = new Option(this.name, this.activityIntensityId);
          dropdownList.add(option, null);
         }
         );
}

/* Add an activity */
function logActivityAdd(){
  var duration = $("section#activity_add #duration_select").val();
  var activityIntensityId =  $("section#activity_add #intensity_select").val();
  var notes = $("section#activity_add #notes_textarea").val();
  var activityTypeId = $("section#activity_add  #activity_type").val();
  var name = $("section#activity_add #name").val();
  var isFavorite;
  if($('section#activity_add .favorite').attr('id') == 'favorite-on') {
    isFavorite = YES;
  } else {
    isFavorite = NO;
  }
  //alert(isFavorite);
  var postData = {
    token: token,
    activityTypeId:activityTypeId,
    activityIntensityId:activityIntensityId,
    name:name,
    duration:duration,
    durationUnit:"minutes",
    datetime: currentDate(),
    notes:notes,
    isFavorite:isFavorite
  };

  log("logActivity: {token=" + token + "&datetime=" + currentDate() + "&activityTypeId=" + currentActivityTypeId
      + "&activityIntensityId=" + activityIntensityId + "&duration=" + duration + "&name=" + name + "&notes=" + notes +
      "&isFavorite=" + isFavorite + "}");

  sendAjax(
           'POST',
           ACTIVITY_ADD_WS ,
           postData,
           logActivitySuccessFunction,
           logActivityErrorFunction
           );
}

/********************************************
  ACTIVITY CHOOSE
*********************************************/

var searchFoodArray, batchIndex;

function onReadyActivityChoose() { startLoadingDataFromDatabase(updatePageActivityChoose); }

/* Update the choose food page details*/
function updatePageActivityChoose(){ generateActivityChoosePage(); }

function generateActivityChoosePage(){
  $('section#choose_activities #list-activities').html("");
  //generate activity type list
  var html = "<ul>";
  html += "<li class='white-container'>Choose from a list of activities types below.</li>";
  var template = "<li class='anchor activitytype selectable' id='?'>?<div class='right'><span class='icon plus'></span></div></li>";
  //populate the list of activity types
  for (var i = 0; i < activityTypeArray.length; i++) {
    var crtItem = activityTypeArray[i];

    html += applyTemplate(template,[crtItem.activityTypeId,crtItem.name]);
  }
  html += "</ul>";

  $('section#choose_activities #list-activities').html(html);

  // Generate favorite activity list
  html = "<ul>";
  html += "<li class='white-container'><h5><span class='star'></span><strong>Choose from a list of favorites.</strong></h5></li>";
  var template = "<li class='activity selectable' id='?'><div class='right'>(? ?)</div>? - ?</li>";
  //  <li class="selectable"><div class="right">(30 minutes)</div>Running 3 miles - Cardio</li>

  //populate the list of favorite activity
  for (var i = 0; i < favoriteActivityArray.length; i++) {
    var crtItem = favoriteActivityArray[i];
    var activityType = getActivityType(crtItem.activityTypeId);

    html += applyTemplate(template,[crtItem.activityId,crtItem.duration,crtItem.durationUnit,crtItem.name,activityType.name]);
  }
  html += "</ul>";

  $('section#choose_activities #list-favorite-activities').html(html);

  Lungo.Notification.hide();
  Lungo.Events.init({
    'tap section#choose_activities article#list-activities-content li.activitytype':
    function() { saveActivityType(this,ACTIVITY_ADD_PAGE); },
    'tap section#choose_activities li.activity': function() {
      createCookie(CURRENT_ACTIVITY_COOKIE,$(this).attr('id'));
      onReadyActivityAdd();
    }
  });
}

/********************************************
  ACTIVITY EDIT
*********************************************/

function onReadyActivityEdit() { startLoadingDataFromDatabase(updatePageActivityEdit);}

/*update the choose food page details*/
function updatePageActivityEdit(){
  log("updateFoodTrackPage");
  updateDurationEditSelect();
  updateIntensityEditSelect();
  currentActivityId = readCookie(CURRENT_ACTIVITY_COOKIE);
  eraseCookie(CURRENT_ACTIVITY_COOKIE);
  var currentActivity = getActivity(currentActivityId);
  currentActivityTypeId = currentActivity.activityTypeId;
  log("Current Activity Type ID: " + currentActivityTypeId);
  var activityType = getActivityType(currentActivity.activityTypeId);
  $("section#activity_update #activity_type").val(currentActivity.activityTypeId);
  $("section#activity_update #duration_select").val(currentActivity.duration);
  $("section#activity_update #intensity_select").val(currentActivity.activityIntensityId);
  $("section#activity_update #notes_textarea").val(currentActivity.notes);
  $("section#activity_update #name").val(currentActivity.name);
  if(currentActivity.isFavorite==1){
    $('section#activity_update .favorite').attr('id','favorite-on');
  } else {
    $('section#activity_update .favorite').attr('id','favorite-off');
  }
  Lungo.Router.section("activity_update");
  //populateFavoriteIcon();
}

/* Generate the drop down duration select */
function updateDurationEditSelect(){
  var dropdownList = $("section#activity_update #duration_select")[0];
  //clear the current options if any
  while(dropdownList.options.length > 0){
    dropdownList.remove(0);
  }

  for(var i=5;i<=60;i+=5){
    var option = new Option(i, i);
    dropdownList.add(option, null);
  }

}

/* Generate the drop down intensity select */
function updateIntensityEditSelect(){
  var dropdownList = $("section#activity_update #intensity_select")[0];
  //clear the current options if any
  while(dropdownList.options.length > 0){
    dropdownList.remove(0);
  }

  $.each(activityIntensityArray,
         function() {
          var option = new Option(this.name, this.activityIntensityId);
          dropdownList.add(option, null);
         }
         );
}

/*add an activity*/
function logActivityUpdate(){
  var duration = $("section#activity_update #duration_select").val();
  var activityIntensityId =  $("section#activity_update #intensity_select").val();
  var activityTypeId = $("section#activity_update #activity_type").val();
  var notes = $("section#activity_update #notes_textarea").val();
  var name = $("section#activity_update #name").val();
  var isFavorite;
  if($('section#activity_update .favorite').attr('id') == 'favorite-on') {
    isFavorite = YES;
  } else {
    isFavorite = NO;
  }
  var postData = {
  token: token,
    activityId:currentActivityId,
    activityTypeId:activityTypeId,
    activityIntensityId:activityIntensityId,
    name:name,
    duration:duration,
    durationUnit:"minutes",
    notes:notes,
    isFavorite:isFavorite
  };

  log("logActivity: {token=" + token + "&activityId=" + currentActivityId + "&datetime=" + currentDate()
      + "&activityTypeId=" + currentActivityTypeId + "&activityIntensityId=" + activityIntensityId
      + "&duration=" + duration + "&name=" + name + "&notes=" + notes + "&isFavorite=" + isFavorite + "}");

  sendAjax(
           'POST',
           ACTIVITY_EDIT_WS ,
           postData,
           logActivitySuccessFunction,
           logActivityErrorFunction
           );
}

/* Delete an activity */
function activityDelete(){
    var postData = {
    token: token,
    activityId: currentActivityId
    };

    log("activityDelete: {" + token + "," + currentActivityId + "}");

    sendAjax(
             'POST',
             ACTIVITY_DELETE_WS ,
             postData,
             activityDeleteSuccessFunction,
             logActivityErrorFunction
             );
}

/* Called when an answer is received from the server */
function activityDeleteSuccessFunction(data){
  log("activityDeleteSuccessFunction");
  log("data = \n---\n" + data +"\n---");

  // Lungo.Notification.show('Deleted Successfully', '', 'check', false, 3);
  loadPage(ACTIVITY_PAGE);
}