/* database functions */

var databaseOptions = {
  fileName: "profile_mobile",
  version: "1.1",
  displayName: "ProfileMobile",
  maxSize: 65536 // 3 MB
};

// open the database
if(!window.openDatabase){
  alert('Local database is not supported on this device.');
} else {
  var database = window.openDatabase(
    databaseOptions.fileName,
    databaseOptions.version,
    databaseOptions.displayName,
    databaseOptions.maxSize
  );
}

function databaseTableCheck(){
  // check if the database exists, if not create it
  var CHECK_TABLE_QUERY = "SELECT name FROM sqlite_master WHERE type='table' AND name='FoodTagLog'";
  databaseSelectQuery(CHECK_TABLE_QUERY,[],createOrNotTheTables);
}

function createOrNotTheTables(results){
  if(results && results.rows.length===0){
    log("tables not found, creating tables");
    createTables();
  } else {
    log("tables already present, no need to create them");
    //createTables();
  }
}


/* general database functions */

// Execute query                   
function databaseQuery(query,values){
  database.transaction(
    function(transaction){
      transaction.executeSql(query,values,function(){},dbErrorHandler);
    }
  );
}

// Execute select query
function databaseSelectQuery(query,values,callback){
  database.transaction(
    function(transaction){
      transaction.executeSql(query,
                        values,
                        function(transaction,results){
                          callback(results);
                        },
                        dbErrorHandler);
    }
  );
}

function dbGetQuery(query, values){
  database.transaction(
    function(transaction){
      transaction.executeSql(query,
                        values,
                        function(transaction, results){
                          return results;
                        },
                        dbErrorHandler
      );
    }
  );
}

// Error handler
function dbErrorHandler(transaction, error) {
  log('Error message = ' + error.message + ' (Code ' + error.code + ')');
  return false;
}

/* specific database functions */

/*create all the tables*/
function createTables(){
  for(var i = 0; i < CREATE_DB_QUERY.length; i++)
  {
    databaseQuery(CREATE_DB_QUERY[i].toString(), []);
  }
}

/* custom food database functions */
function insertCustomFoodTag(foodTag){
  databaseQuery(FOOD_TAG_INSERT_QUERY,[foodTag.foodTagId,
                                        foodTag.name,
                                        foodTag.short,
                                        foodTag.avg_cals,
                                        foodTag.avg_protein,
                                        foodTag.avg_carbs,
                                        foodTag.avg_fat,
                                        foodTag.avg_fiber,
                                        foodTag.for_user_id,
                                        foodTag.color_id]);
}

function deleteCustomFoodTag(foodTagId){
  databaseQuery(CUSTOM_FOOD_TAG_DELETE_QUERY,[foodTagId]);
}

function deleteAllCustomFoodTags(){
  databaseQuery(CUSTOM_FOOD_TAG_DELETE_ALL_QUERY,[]);
}

function getAllCustomFoodTags(callback){
  databaseSelectQuery(CUSTOM_FOOD_TAG_SELECT_ALL_QUERY,[],callback);
}


/* meal database functions */
function insertMeal(meal){
  databaseQuery(MEAL_INSERT_QUERY,[meal.mealId,meal.name]);
}

function deleteAllMeals(){
  databaseQuery(MEAL_DELETE_ALL_QUERY,[]);
}

function getAllMeals(callback){
  databaseSelectQuery(MEAL_SELECT_ALL_QUERY,[],callback);
}

/* food color database functions */
function insertFoodColor(foodColor){
  databaseQuery(FOOD_COLOR_INSERT_QUERY,[foodColor.foodColorId,foodColor.name]);
}

function deleteAllFoodColors(){
  databaseQuery(FOOD_COLOR_DELETE_ALL_QUERY,[]);
}

function getAllFoodColors(callback){
  databaseSelectQuery(FOOD_COLOR_SELECT_ALL_QUERY,[],callback);
}

/* food tag database functions */
function insertFoodTag(foodTag){
  databaseQuery(FOOD_TAG_INSERT_QUERY,[foodTag.foodTagId,
                                        foodTag.name,
                                        foodTag.short,
                                        foodTag.avg_cals,
                                        foodTag.avg_protein,
                                        foodTag.avg_carbs,
                                        foodTag.avg_fat,
                                        foodTag.avg_fiber,
                                        foodTag.for_user_id,
                                        foodTag.color_id]);
}

function deleteAllFoodTags(){
  databaseQuery(FOOD_TAG_DELETE_ALL_QUERY,[]);
}

function getAllFoodTags(callback){
  databaseSelectQuery(FOOD_TAG_SELECT_ALL_QUERY,[],callback);
}

/* favorite food database functions */
function insertFavoriteFoodTag(foodTagId){
  databaseQuery(FAVORITE_FOOD_TAG_INSERT_QUERY,[foodTagId]);
}

function deleteAllFavoriteFoodTags(){
  databaseQuery(FAVORITE_FOOD_TAG_DELETE_ALL_QUERY,[]);
}

function getAllFavoriteFoodTags(callback){
  databaseSelectQuery(FAVORITE_FOOD_TAG_SELECT_ALL_QUERY,[],callback);
}

/* suggested food tag database functions */
function insertSuggestedFoodTag(foodTag){
  databaseQuery(SUGGESTED_FOOD_TAG_INSERT_QUERY,[foodTag.mealId,foodTag.foodTagId,foodTag.servings]);
}

function deleteAllSuggestedFoodTags(){
  databaseQuery(SUGGESTED_FOOD_TAG_DELETE_ALL_QUERY,[]);
}

function getAllSuggestedFoodTags(callback){
  databaseSelectQuery(SUGGESTED_FOOD_TAG_SELECT_ALL_QUERY,[],callback);
}

function getSuggestedFoodTagsByMeal(mealId, callback){
  databaseSelectQuery(SUGGESTED_FOOD_TAG_SELECT_BY_MEAL_QUERY, [mealId], callback);
}

/* food tag log database functions */
function insertFoodTagLog(foodTagLog){
  databaseQuery(FOOD_TAG_LOG_INSERT_QUERY,[foodTagLog.mealId,foodTagLog.foodTagId,foodTagLog.consumedDate,foodTagLog.servings]);
}

function deleteAllFoodTagLogs(){
  databaseQuery(FOOD_TAG_LOG_DELETE_ALL_QUERY,[]);
}

function getAllFoodTagLogs(callback){
  databaseSelectQuery(FOOD_TAG_LOG_SELECT_ALL_QUERY,[],callback);
}


/* common food database functions */
function insertCommonFood(commonFood){
  databaseQuery(COMMON_FOOD_INSERT_QUERY,[commonFood.commonFoodId,commonFood.foodId]);
}

function deleteAllCommonFoods(){
  databaseQuery(COMMON_FOOD_DELETE_ALL_QUERY,[]);
}

function getAllCommonFoods(callback){
  databaseSelectQuery(COMMON_FOOD_SELECT_ALL_QUERY,[],callback);
}

/* user's plan */
function insertCurrentPlan(plan){
  databaseQuery(PLAN_INSERT_QUERY,[plan.id, plan.template_name, plan.activity_text, plan.date_started]);
}

function deleteCurrentPlan(){
  databaseQuery(PLAN_DELETE_ALL_QUERY,[]);
}

function getCurrentPlan(callback){
  databaseSelectQuery(PLAN_SELECT_QUERY, [], callback);
}

function insertVariable(variable){
  databaseQuery(VARIABLE_INSERT_QUERY, [variable.name, variable.value]);
}
function updateVariable(variable){
  databaseQuery(VARIABLE_UPDATE_QUERY, [variable.value, variable.name]);
}
function deleteVariable(variable){
  databaseQuery(VARIABLE_DELETE_QUERY, [variable.name]);
}
function getVariable(variableName){
  return dbGetQuery(VARIABLE_SELECT_QUERY, [variableName]);
}


/*return an array of food properties*/
function foodToArray(food){
  return [food.foodId,
          food.foodTypeId,
          food.foodColorId,
          food.isDeleted,
          food.name,
          food.servingSize,
          food.servingUnit,
          food.calories ,
          food.caloriesFat,
          food.totalFat,
          food.saturatedFat,
          food.transFat,
          food.cholesterol,
          food.sodium,
          food.potassium,
          food.totalCarbs,
          food.dietaryFiber,
          food.protein,
          food.sugars];
}

/*return an array of food properties*/
function customFoodToArray(food){
  return [food.foodId,
          food.foodTypeId,
          food.foodColorId,
          food.isDeleted,
          food.name,
          food.servingSize,
          food.servingUnit,
          food.calories ,
          food.caloriesFat,
          food.totalFat,
          food.saturatedFat,
          food.transFat,
          food.cholesterol,
          food.sodium,
          food.potassium,
          food.totalCarbs,
          food.dietaryFiber,
          food.protein,
          food.sugars,
          food.foodTagId];
}

function foodTagToArray(foodTag){
  return [foodTag.foodTagId,
          foodTag.name,
          foodTag.short,
          foodTag.avg_cals,
          foodTag.avg_protein,
          foodTag.avg_carbs,
          foodTag.avg_fat,
          foodTag.avg_fiber,
          foodTag.food_user_id,
          foodTag.color_id];
}

//========== ACTIVITY SECTION ============

/* activity type database functions */
function insertActivityType(activityType){
  databaseQuery(ACTIVITY_TYPE_INSERT_QUERY,[activityType.activityTypeId,activityType.name]);
}

function deleteAllActivityTypes(){
  databaseQuery(ACTIVITY_TYPE_DELETE_ALL_QUERY,[]);
}

function getAllActivityTypes(callback){
  databaseSelectQuery(ACTIVITY_TYPE_SELECT_ALL_QUERY,[],callback);
}


/* activity Intensity database functions */
function insertActivityIntensity(activityIntensity){
  databaseQuery(ACTIVITY_INTENSITY_INSERT_QUERY,[activityIntensity.activityIntensityId,activityIntensity.name]);
}

function deleteAllActivityIntensities(){
  databaseQuery(ACTIVITY_INTENSITY_DELETE_ALL_QUERY,[]);
}

function getAllActivityIntensities(callback){
  databaseSelectQuery(ACTIVITY_INTENSITY_SELECT_ALL_QUERY,[],callback);
}

/* activity database functions */
function insertActivity(activity){
  databaseQuery(ACTIVITY_INSERT_QUERY,[activity.activityId, 
                                activity.activityTypeId, 
                                activity.activityIntensityId, 
                                activity.name,
                                activity.duration,
                                activity.durationUnit,
                                activity.date_time,
                                activity.notes,
                                activity.isFavorite]);
}

function deleteAllActivities(){
  databaseQuery(ACTIVITY_DELETE_ALL_QUERY,[]);
}

function getAllActivities(callback){
  databaseSelectQuery(ACTIVITY_SELECT_ALL_QUERY,[],callback);
}

/* activity database functions */
function insertFavoriteActivity(activity){
  insertActivity(activity);
}

function deleteAllFavoriteActivities(){
  databaseQuery(FAVORITE_ACTIVITY_DELETE_ALL_QUERY,[]);
}

function getAllFavoriteActivities(callback){
  databaseSelectQuery(FAVORITE_ACTIVITY_SELECT_ALL_QUERY,[],callback);
}

/*return an array of activity properties*/
function activityToArray(activity){
  return [activity.activityId,
          activity.activityTypeId,
          activity.activityIntensityId,
          activity.name,
          activity.duration,
          activity.durationUnit,
          activity.datetime,
          activity.notes,
          activity.isFavorite
          ];
}

/* Journal */
function deleteAllJournals(){
  databaseQuery(JOURNAL_DELETE_ALL_QUERY,[]);
}

function insertJournal(journal){
  databaseQuery(JOURNAL_INSERT_QUERY,[journal.id, 
                                journal.is_private, 
                                journal.title,
                                journal.mood,
                                journal.notes,
                                journal.date_time]);
}

function getAllJournals(callback){
  databaseSelectQuery(JOURNAL_SELECT_ALL_QUERY,[],callback);
} 

