var fluidCnt, foodListArray;

function onReadyFood() {
  Lungo.Notification.show();
  document.addEventListener("backbutton", onBackKeyDown, false);
  
  // Food page on load
  var crtDate = currentDate();

  if(crtDate==todayDate()){
    $("#tomorrow_button").hide();
  } else {
    Lungo.Events.init({
      'tap #tomorrow_button': tomorrow
    });
  }
  $("#current_date_span").text(niceFormatDate(currentDate()));

  // Check static data
  checkNewStaticData(enableOrNotTheCloudButton);
}

function enableOrNotTheCloudButton(yesOrNo){
  if(yesOrNo==YES) {
    $("#cloud_button").show();
     updateStaticData(updateFoodPage);
  } else {
    updateFoodPage();
  }
}

/*update the daily food page details*/
function updateFoodPage(){
  log("Update food page");
  var postData = {
    token: token,
    date: currentDate(),
    dataname:"User,FoodTagLog,FavoriteFoodTag,Fluid,CustomFoodTag,SuggestedFoodTag,Plan"
  };
  sendAjax(
           'POST',
           DYNAMIC_DATA_WS,
           postData,
           updateFoodPageSuccess,
           onError
           );
}

function updateFoodPageSuccess(data){

  var dataObject = parseJSON(data);

  //check if the user is still logged in
  if(isUserLoggedIn (dataObject) == NO){
    eraseCookie(TOKEN_COOKIE_NAME);
    loadPage(LOGIN_PAGE);
    return;
  }

  if(dataObject !== null) {
    // User's name
    setMenuTitle(dataObject.UserInfo);

    // Fluid intake
    var fluid = dataObject.Fluid;

    fluidCnt = fluid.cnt;
    if(fluidCnt<=0) {
      fluidCnt = 0;
    }

    displayFluids(fluidCnt);

    var array = [];

    // User's plan
    var plan = dataObject.Plan;
    displayPlanInfo(plan);

    // Custom Food Tag
    array = dataObject.CustomFoodTag;
    if(typeof array !== 'undefined' && array !== null){
      deleteAllCustomFoodTags();
      for (var j = 0; j < array.length; j++) {
        insertCustomFoodTag(array[j]);
      }
    }

    // Favorite food tag
    array = dataObject.FavoriteFoodTag;
    if(typeof array !== 'undefined' && array !== null){
      deleteAllFavoriteFoodTags();
      for (var k = 0; k < array.length; k++) {
        insertFavoriteFoodTag(array[k]);
      }
    }

    // Food intake
    array = dataObject.FoodTagLog;
    if(typeof array !== 'undefined' && array !== null){
      deleteAllFoodTagLogs();
      for (var l = 0; l < array.length; l++) {
        insertFoodTagLog(array[l]);
      }
    }
    getSuggestedAndFoodIntakeList(plan);
  }
}


function getSuggestedAndFoodIntakeList(plan){
  var planId = 0;
  if(plan){
    planId = parseInt(plan["info"]["id"], 10);
  }
  var post = {
    token: token,
    date: currentDate(),
    planId: planId
  };
  sendAjax(
    'POST',
     SUGGESTED_AND_FOOD_INTAKE_WS,
     post,
     createSuggestedAndFoodIntakeListArray,
     onError
  );
}

function createSuggestedAndFoodIntakeListArray(data){
  if(data !== null){
    var json = parseJSON(data);
    if(json !== null){
      foodListArray = json.FoodList;
    }
  }
  startLoadingDataFromDatabase(startUpdatingPage);
}

function startUpdatingPage(){
  generateFoodPage();
}

/* Fluid functions */
/* Update the UI for the fluid section */
function updateFluid(fluidCnt){
  //update the server
  var postData = {
    token:token,
    date:currentDate(),
    cnt:fluidCnt
  };
  //to be enabled after the WS is done
  sendAjax ("POST", FLUID_WS, postData);
}

/* Save the meal id for future use*/
function addFoodForMeal(mealId) {
  createCookie(CURRENT_MEAL_COOKIE, mealId);
  Lungo.Router.section("choose_food");
}

/* Save the mealToFoodId for future use */
function saveMealToFood(control) {
  createCookie(CURRENT_FOOD_TAG_COOKIE,control.attr("foodtagid"));
  createCookie(CURRENT_MEAL_TYPE_COOKIE,control.attr("mealid"));
  onReadyFoodEdit();
}

/* Generate the table of meals */
function generateFoodPage(){
  log("Generate food page");
  var wrap = $('section#food #food_div');
  var foodDivElement = $('<ul>');
  var mealCount = 0;
  for (var i = 0; i < mealArray.length; i++) {
    var hasFood = NO;
    var crtMeal = mealArray[i];

    var template = "<li class='anchor meal' id='?'><div class='right'><span class='icon plus'></span></div>?</li>";
    var crtFoodHtml = applyTemplate(template,[crtMeal.mealId,crtMeal.name]);

    foodDivElement.append(crtFoodHtml);
    // Loop through food intake
    var mealId = parseInt(crtMeal.mealId, 10);

    if(typeof foodListArray[mealId] !== 'undefined' && foodListArray[mealId] !== null){
      // try to find the foods for this meal

      for(var j=0 ; j<foodListArray[mealId].length ; j++){
        var foodItem = foodListArray[mealId][j];
        var colorName = foodItem["colorName"].toString();
        var foodTagId = parseInt(foodItem["foodTagId"], 10);
        var foodName = foodItem["name"].toString();
        var consumed = "";
        var suggested = "";
        var crossed = "";
        if(parseInt(foodItem["consumed"], 10) > 0){
          consumed = "(" + foodItem["consumed"] + "x)";
          crossed = "consumed ";
        }
        if(parseInt(foodItem["suggested"], 10) > 0){
          suggested = "<small>Suggested: " + foodItem["suggested"] + " servings</small>";
        } else {
          suggested = "<small>Not suggested</small>";
        }
        var temp = "<li class='" + crossed + colorName + "_label food' mealId='" + crtMeal.mealId + "' foodTagId='" + foodTagId + "' consumed='" + foodItem["consumed"] + "' suggested='" + foodItem["suggested"] + "'><div class='right'><span class='icon pencil'></span></div>" + foodName + " " + consumed + suggested + "</li>";
        foodDivElement.append(temp);
      }
    }

    if(hasFood==YES){
      mealCount++;
    }
  }

  $("#meal_count_span").text(mealCount);


  wrap.html(foodDivElement);
  Lungo.Notification.hide();

  // $$("#food_div ul li.food").swipeLeft(addFoodTagLog($(this)));
  // $$("#food_div ul li.food").swipeRight(removeFoodTagLog($(this)));

  Lungo.Events.init({
    'tap section#food li.meal .right': function() { addFoodForMeal($(this).parent('li').attr("id")); },
    'tap section#food li.food .right': function() { saveMealToFood($(this).parent('li')); },
    'swipeLeft #food_div ul li.food': function() { addFoodTagLog($(this)); return false; },
    'swipeRight #food_div ul li.food': function() { removeFoodTagLog($(this)); return false; },

    'doubleTap #food_div ul li.food': function() { addFoodTagLog($(this)); return false; },
    'hold #food_div ul li.food': function() { removeFoodTagLog($(this)); return false; }
  });
}

function displayFluids(glass_total){
  var value = parseInt(glass_total, 10);
  $('.water-tank').text(value);
  $('#water_range').attr('value', value);
}

function addFoodTagLog(control){
  var consumed = parseInt(control.attr("consumed"), 10);
  var suggested = parseInt(control.attr("suggested"), 10);
  if(consumed === 0){
    control.addClass("consumed");
    updateFoodTagLog(control.attr("mealid"), control.attr("foodtagid"), suggested);
  }
}

function removeFoodTagLog(control){
  var consumed = parseInt(control.attr("consumed"), 10);
  if(consumed > 0){
    control.removeClass("consumed");
    deleteFoodTagLog(control.attr("mealid"), control.attr("foodtagid"));
  }
}

function updateFoodTagLog(mealId, foodTagId, consumed){
  var post = {
    token: token,
    dateConsumed: currentDate(),
    foodTagId: foodTagId,
    oldMealId: mealId,
    newMealId: mealId,
    servings: consumed
  };
  sendAjax(
     'POST',
     LOG_FOOD_TAG_EDIT_WS,
     post,
     updateFoodPage,
     onError
  );
}

function deleteFoodTagLog(mealId, foodTagId){
  var post = {
    token: token,
    date: currentDate(),
    foodTagId: foodTagId,
    mealTypeId: mealId
  };
  sendAjax(
    'POST',
     LOG_FOOD_TAG_REMOVE_WS,
     post,
     updateFoodPage,
     onError
  );
}

