/* constants */

var SUCCESS = "success";

// cookie name for storing the authorization token 
var TOKEN_COOKIE_NAME         = "token";

//page names
var LOGIN_PAGE                = "../login.html";
var FOOD_PAGE_FROM_LOGIN      = "food_m/food.html";
var FOOD_PAGE                 = "food.html";
var FOOD_CHOOSE_PAGE          = "food-choose.html";
var FOOD_EDIT_PAGE            = "food-edit.html";
var FOOD_ADD_PAGE             = "food-add.html";
var FOOD_TAG_PAGE             = "food-tag.html";
var FOOD_CUSTOM_SELECTED_PAGE = "food-custom-selected.html";
var FOOD_CUSTOM_EDIT_PAGE     = "food-custom-edit.html";

var ACTIVITY_PAGE             = "activity.html";
var ACTIVITY_CHOOSE_PAGE      = "activity-choose.html";
var ACTIVITY_ADD_PAGE         = "activity-add.html";
var ACTIVITY_EDIT_PAGE        = "activity-edit.html";

var JOURNAL_PAGE              = "journal.html";
var JOURNAL_ADD_PAGE          = "journal-add.html";
var JOURNAL_EDIT_PAGE         = "journal-edit.html";

var LOGOUT_WS                 = "curruser/logoutuser";

var ERROR_NOT_LOGGED_IN = "not logged in";

var ERROR_NOT_LOGGED_IN_CODE = "60";

var YES=1, NO=0;
/* end of constants*/

/* general utilities functions*/

//create a cookie
function createCookie(name,value,days) {
  window.localStorage.setItem(name, value);
}

//read a cookie
function readCookie(name) {
	return window.localStorage.getItem(name);
}

//erase cookie
function eraseCookie(name) {
	window.localStorage.removeItem(name);
}

/*change an array into a comma separated string*/
function arrayStringify(array){
  var result = "(";
  if(array.length>=1){
    result += array[0];
  }
  for(i=1;i<array.length;i++){
    result += ", " + array[i];
  }
  result += ")";
  return result;
}

/*parse a JSON string into an object */
function parseJSON(data){
  if(typeof data == "string"){
    var jsonObj = null;
    try {
      jsonObj = JSON.parse (data);
    } catch (e) {
      alert ("JSON Error: " + e);
    }
    return jsonObj;
  }
  return data;
}


function log(message){
  var url = window.location.pathname;
  var filename = url.substring(url.lastIndexOf('/')+1);
  console.log(filename + " : " + message);
}

/*make an AJAX call*/
function sendAjax (type, url, data, success, error){
  $.ajax({
         type: type,
         url: url,
         data: data,
         cache: false,
         success: success,
         error: error
         });
}

function onError(xhr, ajaxOptions, thrownError){
  log("Connection error: " + xhr.status + " - " + thrownError);
  Lungo.Notification.hide();
}

/* function used to extract the error messages from a web service return */
function errorToString (dataObject){
  if(dataObject==null) return null;
  if(dataObject.error==null) return null;
  var error = dataObject.error;

  var errorMessage="";
  for(var i=0;i<error.length;i++){
    errorMessage += error[i].msg + " (" + error[i].code + ")\n" ;
  }
  return errorMessage;
}

/* function used to extract the error messages from a web service return */
function isUserLoggedIn (dataObject){

  if(dataObject==null) return NO;

  if(dataObject.error==null) return YES;

  var error = dataObject.error;

  var errorMessage="";
  for(var i=0;i<error.length;i++){
    if(error[i].code == ERROR_NOT_LOGGED_IN_CODE){
      alert("Login session has expired. Redirecting you to the login page");
      return NO;
    }
  }
  return YES;
}


function loadPage(url){
  //to prevent the caching of the page, we add a fake paramter at the end: paramnocache=random nr
  window.location  = url;
}

function applyTemplate(template,values){
  var result = template;
  for(var i=0;i<values.length;i++){
    result = result.replace ("?",values[i]);
  }
  return result;
}

/*function disableAllControls(){
  Lungo.Notification.loading();
  log("disableAllControls");
  $(":input").attr("disabled","disabled");
  $("a").attr("disabled","disabled");
}*/

/*
function enableAllControls(){
  log("enableAllControls");
  Lungo.Notification.hide();
  $(":input").removeAttr('disabled');
  $("a").removeAttr('disabled');
}*/

function goBack() {
  window.history.back();
}

function checkConnection() {
    log("Connected: " + navigator.onLine);
    var isAndroid = navigator.userAgent.match(/(Android)/);
    if(!navigator.onLine && !isAndroid){
      Lungo.Notification.error("Connection Error", "No network connection detected. Profile App requires connection to the internet. <a id='refresh_app'>Refresh</a>", "warning", 0);
      Lungo.Events.init({
        'tap a#refresh_app': function() {window.location.reload();}
      });
      return false;
    } else {
      return true;
    }
}

function setMenuTitle(userInfo){
  if(userInfo){
    var str = '<span class="aside_title centered">' + userInfo["firstName"] + ' ' + userInfo["lastName"] + '</span>';
    $("header#menu_title").html(str);
  }
}

function displayPlanInfo(plan){
  $("#plan_name").html(plan["info"]["template_name"]);
  $(".plan_name").html(plan["info"]["template_name"]);
  // Calculate plan days
  var diff = parseInt(plan["info"]["daysonplan"], 10) + 1;
  $("#plan_days").html(diff);
  $(".plan_days").html(diff);
  var str = '<span class="sub_title centered"><strong>Day </strong>' + diff + ' of ' + plan["info"]["template_name"] + '</span>';
  $("header#menu_title").append(str);
}

function logOut(){
  var post = {
            token: token
          };
  sendAjax(
      "POST",
      SERVER_WS + LOGOUT_WS,
      post,
      logOutSuccess,
      onError
  );
}

function logOutSuccess(){
  eraseCookie(TOKEN_COOKIE_NAME);
  loadPage(LOGIN_PAGE);
}

function removeAutoFocus() {
   $('input').bind('focus', function(e) { $(this).blur(); });
   $('select').bind('focus', function(e) { $(this).blur();  });
   $('textarea').bind('focus', function(e) { $(this).blur(); });
}

function onBackKeyDown(){
  var activeSection = readCookie("activeSection");
  if(activeSection == "home"){
    if(typeof (navigator.app) !== "undefined"){
      navigator.app.exitApp();
    } else {
      device.exitApp();
    }
  } else {
    if(typeof (navigator.app) !== "undefined"){
      navigator.app.backHistory();
    } else {
      window.history.back();
    }
  }
}

